function [diagnostic,jsrellips]=EllipsNorm_v07(t,erre,epsilon,StartingStep,precisionJSR)

% ELLIPSNORM    Ellipsoidal Norm evaluation. 
%
% function [jsrellips,diagnostic]=EllipsNorm(t,erre,epsilon,StartingStep)
%
% Input:
%   t             Length of matrix products
%   erre          Possible estimate for the Joint Spectral Radius
%   epsilon       Usually fixed to 10^-9
%   StartingStep  Step in which we start to cut branches 
%  
%  Output:
%    diagnostic   Struct containing information about the Semidefinite
%                 Optimization
%    jsrellips    Positive definite matrix
% 
%  NB:
%    1) Ellipsoidal Norms generalize the Spectral norm for matrices.
%    2) This algorithm requires the following global variables to be
%        defined: P, Pcut, dry, alfa, branch, M.
%    3) Change variable ops inside the code to display more
%
%   See also JSR_V10, RECTNORM_V07.
%

global P Pcut dry alfa branch M;

s=size(P.L1.A1);% Dimensions of the matrices of the family

X=sdpvar(s(1),s(1));

F=set(X>0);% In this way we define the inequality X>0


for k=1:t
    sizeDry_k=size(dry.(['branch' int2str(k)]));
    for kk=1:sizeDry_k(2)
        F=F+set((Pcut.(['L' int2str(k)]).(['A' int2str(dry.(['branch' int2str(k)])(k,kk))]))'*X*(Pcut.(['L' int2str(k)]).(['A' int2str(dry.(['branch' int2str(k)])(k,kk))]))-(alfa(t)+precisionJSR)^(2*k)*X<=0);% In this way we define the inequality P_s'*X*P_s<=alfa_{t}^{2s}*X 
    end
end

if t>StartingStep % we use this program inside a loop s.t. t>=StartingStep
    siz=size(branch.(['es' int2str(t-1)]));% Number of columns==Number of matrices of length 't-1' in the semigroup
    for k=1:siz(2)
        lengthP=M.(['set' int2str(t-1)])(k);% Length of Product with minimal norm
        F=F+set((P.(['L' int2str(lengthP)]).(['A' int2str(branch.(['es' int2str(t-1)])(lengthP,k))]))'*X*(P.(['L' int2str(lengthP)]).(['A' int2str(branch.(['es' int2str(t-1)])(lengthP,k))]))-erre^(2*lengthP)*X<=0);
        % In this way we define the inequality P_i'*X*P_i<=erre^{2*lengthP_i}*X for
        % P_i in set M_{t-1}
    end
else% we are in the special case t=StartingStep
    siz=size(branch.(['es' int2str(t)]));% Number of columns==Number of matrices of length 't' in the semigroup
    for k=1:siz(2)
        % t = Length of Product we are considering at step t=StartingStep
        F=F+set((P.(['L' int2str(t)]).(['A' int2str(branch.(['es' int2str(t)])(t,k))]))'*X*(P.(['L' int2str(t)]).(['A' int2str(branch.(['es' int2str(t)])(t,k))]))-erre^(2*t)*X<=0);
        % In this way we define the inequality P_t'*X*P_t<=erre^{2t}*X for
        % all products of length t
    end
end

% F=F+set(trace(X)<=2);% In this way we add the equality in brackets to the system F
% F=F+set(trace(X)>=1);
F=F+set(1<=trace(X)<=3);

ops = sdpsettings('verbose',0,'showprogress',0);
diagnostic = solvesdp(F,X);%,ops); % We solve the system of inequality F
checkset(F);% We check the result
jsrellips=double(X); % we rewrite the solution in double format