%%---------------------------------------------
%-----------Barthlemy & Marx (2018)-----------
%----------------------------------------------
% Name of the graph in the paper: Figure 1 and 3
% Graph of determinacy and indeterminacy
% Need around around 10 hours when parallelized on 4 cores (standard machine in 2015).
% General idea: 
%    1. initialization for q=5 (maximization over norms)
%    2. maximization over norms for q=15
%    3. we push q to 19 and use the optimized norm from last step only if close to determinacy from step 2
%%---------------------------------------------

norm_= 1; % choice of the norm
alpha1=[1:0.1:3.5];alpha2=[0.96:0.005:1]; % grid for alphas
t0=[1.09;-0.15;0.9]; % initialization for optimization over norms
p_11=0.8;p_22=0.95; % probabilities
qq=5; % lenght of sequence uk in the first 2 steps
deterzone=NaN*ones(size(alpha1,2),size(alpha2,2))
init=NaN*ones(3,size(alpha1,2),size(alpha2,2))

%ALTERNATIVE 1: MAXIMIZATION OVER NORMS for qq=5 (very short but imprecise)
qq=5
parfor i=1:size(alpha1,2)
    i
    tic
    for j=1:9
       [init(:,i,j),deterzone(i,j)]=def_model_optim(alpha1(i),alpha2(j),p_11,p_22,t0,qq,norm_);

    end
    toc
end;

%ALTERNATIVE 2: MAXIMIZATION OVER NORMS for qq=15 using previous directions 'init' (5 hours for 4 cores)
qq=15
parfor i=1:size(alpha1,2)
    i
    tic
    for j=1:9
       [init(:,i,j),deterzone(i,j)]=def_model_optim(alpha1(i),alpha2(j),p_11,p_22,init(:,i,j),qq,norm_);

    end
    toc
end;

save deter_save_final.mat alpha1 alpha2 deterzone

%ALTERNATIVE 3: we push as far as we can u_q using the optimized norm from step 2 (3 hours for 4 cores)
qq=20
tic
parfor i=1:size(alpha1,2)
    i
    tic
    for j=1:9
            deterzone(i,j)=optim_expo(init(:,i,j),alpha1(i),alpha2(j),p_11,p_22,qq,norm_) %second best
    end
    toc
end;
qq_save=qq;
save deter_save_final.mat alpha1 alpha2 deterzone qq_save


load deter_save_final.mat alpha1 alpha2 deterzone qq_save
% GRAPH OF DETERMINACY
alpha1_forgraph=alpha1;
alpha2_forgraph=[0.94 alpha2];
deterzone_forgraph=[2*ones(size(alpha1,2),1) deterzone]

[GRID_1,GRID_2]=meshgrid(alpha1_forgraph,alpha2_forgraph);

scrsz = get(0,'ScreenSize');
 figure1 =figure('Position',[1 1 scrsz(4) scrsz(4)],'PaperSize',[20 20],...
    'Color',[1 1 1])
    axes1 = axes('Parent',figure1,...
    'Position',[0.15 0.2 0.75 0.75],...
    'FontSize',30,...
    'FontName','Times');
    box(axes1,'on');
    hold(axes1,'all');
h=contourf(GRID_1,GRID_2,(deterzone_forgraph)',[1 1],'LineWidth',1);
hold on;
%h2=contourf(GRID_1,GRID_2,deter',[1 1],'LineWidth',1);
colormap([[0.3 0.3 0.3];[0.6 0.6 0.6];[1 1 1]])

axis square;
xlabel('\alpha_1','FontName','Times','FontSize',30)
ylabel('\alpha_2','FontName','Times','FontSize',30)
set(gca,'Layer','top')    
set(gca, 'Color', 'none');
xlim([alpha1(1) alpha1(end)])
ylim([0.94 alpha2(end)])
% set(gca,'XTick',[0.01 0.25 0.5 0.75 0.99])
% set(gca,'XTickLabel',{0;0.25;0.5;0.75;1})
% set(gca,'YTick',[0.01 0.25 0.5 0.75 0.99])
% set(gca,'YTickLabel',{0;0.25;0.5;0.75;1})
saveas(figure1,'DET.fig')
export_fig DET.pdf -painters -transparent


%GRAPH INDETERMINACY WITH CYCLES

load deter_save_final.mat alpha1 alpha2 deterzone  qq_save
alpha1_forgraph=alpha1;
alpha2_forgraph=[0.90 alpha2];
deterzone_forgraph=[2*ones(size(alpha1,2),1) deterzone]
[GRID_1,GRID_2]=meshgrid(alpha1_forgraph,alpha2_forgraph);

load \sunspots\BACKUP_CLEAN_mid

scrsz = get(0,'ScreenSize');
 figure1 =figure('Position',[1 1 scrsz(4) scrsz(4)],'PaperSize',[20 20],...
    'Color',[1 1 1])
    axes1 = axes('Parent',figure1,...
    'Position',[0.15 0.2 0.75 0.75],...
    'FontSize',30,...
    'FontName','Times');
    box(axes1,'on');
    hold(axes1,'all');
h=contourf(GRID_1,GRID_2,(deterzone_forgraph)',[1 1],'LineWidth',3);
colormap([[1 1 1];[1 1 1];[1 1 1]])
hold on;
%h2=contourf(GRID_1,GRID_2,deter',[1 1],'LineWidth',1);
plot(alpha_1,[1;alpha_2_dl(2:end)'],'k-x','LineWidth',3,'MarkerSize',12);

plot(alpha_1,[1;alpha_2_NCYCLE(2:end,1)],'k:','LineWidth',3);
plot(alpha_1,[1;alpha_2_NCYCLE(2:end,2)],'k:','LineWidth',3);
plot(alpha_1,[1;alpha_2_NCYCLE(2:end,3)],'k:','LineWidth',3);
plot(alpha_1,[1;alpha_2_NCYCLE(2:end,4)],'k:','LineWidth',3);
plot(alpha_1,[1;alpha_2_NCYCLE(2:end,5)],'k:','LineWidth',3);
plot(alpha_1,[1;alpha_2_NCYCLE(2:end,6)],'k:','LineWidth',3);

axis square;
xlabel('\alpha_1','FontName','Times','FontSize',30)
ylabel('\alpha_2','FontName','Times','FontSize',30)
set(gca,'Layer','top')    
set(gca, 'Color', 'none');
xlim([alpha1(1) 2.2])
ylim([0.91 alpha2(end)])
annotation(figure1,'textbox',...
    [0.81 0.42 0.092 0.10],...
    'String',{'q=1'},...
    'FontSize',18,...
    'FontName','Times New Roman',...
    'LineStyle','none');

annotation(figure1,'textbox',...
    [0.69 0.46 0.092 0.10],...
    'String',{'q=2'},...
    'FontSize',18,...
    'FontName','Times New Roman',...
    'LineStyle','none');

annotation(figure1,'textbox',...
    [0.61 0.468 0.092 0.10],...
    'String',{'q=3'},...
    'FontSize',18,...
    'FontName','Times New Roman',...
    'LineStyle','none');

annotation(figure1,'textbox',...
    [0.61 0.492 0.092 0.10],...
    'String',{'q=4'},...
    'FontSize',18,...
    'FontName','Times New Roman',...
    'LineStyle','none');

annotation(figure1,'textbox',...
    [0.536 0.476 0.092 0.10],...
    'String',{'q=5'},...
    'FontSize',18,...
    'FontName','Times New Roman',...
    'LineStyle','none');

annotation(figure1,'textbox',...
    [0.48 0.475 0.092 0.10],...
    'String',{'q=6'},...
    'FontSize',18,...
    'FontName','Times New Roman',...
    'LineStyle','none');

saveas(figure1,'INDET.fig')
export_fig INDET.pdf -painters -transparent
